# -*- coding: utf-8 -*-
from compat import get_user_model
from django.contrib import admin
from django.contrib.auth.admin import UserAdmin
from django.core.urlresolvers import reverse
from django.template import Context
from django.template.loader import get_template
from django.utils.translation import ugettext as _

from hijack import settings as hijack_settings


class HijackUserAdminMixin(object):
    def hijack_field(self, obj):
        hijack_attributes = hijack_settings.HIJACK_URL_ALLOWED_ATTRIBUTES

        if 'user_id' in hijack_attributes:
            hijack_url = reverse('login_with_id', args=(obj.pk, ))
        elif 'email' in hijack_attributes:
            hijack_url = reverse('login_with_email', args=(obj.email, ))
        else:
            hijack_url = reverse('login_with_username', args=(obj.username, ))

        button_template = get_template('hijack/admin_button.html')
        button_context = Context({
            'hijack_url': hijack_url,
            'username': str(obj),
        })
        return button_template.render(button_context)

    hijack_field.allow_tags = True
    hijack_field.short_description = _('Hijack user')


class HijackUserAdmin(HijackUserAdminMixin, UserAdmin):
    list_display = ('username', 'email', 'first_name', 'last_name',
                    'last_login', 'date_joined', 'is_staff', 'hijack_field', )
    list_filter = ('is_staff', 'is_superuser')
    search_fields = ('username', 'first_name', 'last_name', 'email', )

# By default show a Hijack button in the admin panel for the User model.
if hijack_settings.HIJACK_DISPLAY_ADMIN_BUTTON:
    UserModel = get_user_model()
    admin.site.unregister(UserModel)
    admin.site.register(UserModel, HijackUserAdmin)



from django import template
from django.utils.safestring import mark_safe
from django.template.loader import render_to_string
from django.template import RequestContext
from compat import import_string

from hijack import settings as hijack_settings

register = template.Library()


# Deprecated. Use the template tag below
@register.filter
def hijackNotification(request):
    return _render_hijack_notification(request)


@register.simple_tag(takes_context=True)
def hijack_notification(context):
    request = context['request']
    return _render_hijack_notification(request)


def _render_hijack_notification(request):
    if hijack_settings.HIJACK_USE_BOOTSTRAP:
        template_name = 'hijack/notifications_bootstrap.html'
    else:
        template_name = 'hijack/notifications.html'
    ans = ''
    if (hijack_settings.HIJACK_DISPLAY_WARNING and
            request and
            request.session.get('is_hijacked_user', False) and
            request.session.get('display_hijack_warning', False)
        ):
        ans = render_to_string(template_name, {},
                               context_instance=RequestContext(request))
    return mark_safe(ans)


@register.filter
def can_hijack(hijacker, hijacked):
    check_authorization = import_string(hijack_settings.HIJACK_AUTHORIZATION_CHECK)
    return check_authorization(hijacker, hijacked)



from django.dispatch import Signal

post_superuser_login = Signal(providing_args=['user_id'])

post_superuser_logout = Signal(providing_args=['user_id'])

hijack_started = Signal(providing_args=['hijacker_id', 'hijacked_id'])
hijack_ended= Signal(providing_args=['hijacker_id', 'hijacked_id'])



# -*- encoding: utf-8 -*-
from compat import import_string

from hijack import settings as hijack_settings

def hijack_decorator(fn):
    decorator = import_string(hijack_settings.HIJACK_DECORATOR)
    return decorator(fn)


from compat import url

from hijack import settings as hijack_settings
from hijack.views import release_hijack, disable_hijack_warning, login_with_id, login_with_email, login_with_username

urlpatterns = [
    url(r'^release-hijack/$', release_hijack, name='release_hijack')
]

if hijack_settings.HIJACK_DISPLAY_WARNING:
    urlpatterns.append(url(r'^disable-hijack-warning/$', disable_hijack_warning, name='disable_hijack_warning'))

hijacking_user_attributes = hijack_settings.HIJACK_URL_ALLOWED_ATTRIBUTES
if 'email' in hijacking_user_attributes:
    urlpatterns.append(url(r'^email/(?P<email>[^@]+@[^@]+\.[^@]+)/$', login_with_email, name='login_with_email'))
if 'username' in hijacking_user_attributes:
    urlpatterns.append(url(r'^username/(?P<username>.*)/$', login_with_username, name='login_with_username'))
if 'user_id' in hijacking_user_attributes:
    urlpatterns.append(url(r'^(?P<user_id>[\w-]+)/$', login_with_id, name='login_with_id'))
